@@ -1,5 +1,5 @@
 /*
-//@line 42 "/export/home/mozilla/uild/thunderbird-2.0.0.0/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 42 "/export/home/mozilla/uild/thunderbird-2.0.0.9/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
 */
 
 /* This file implements the nsIHelperAppLauncherDialog interface.
@@ -99,9 +99,9 @@ nsUnknownContentTypeDialog.prototype = {
           if (aFolderType != "Downloads")
             throw "ASSERTION FAILED: folder type should be 'Desktop' or 'Downloads'";
         
-//@line 147 "/export/home/mozilla/uild/thunderbird-2.0.0.0/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 147 "/export/home/mozilla/uild/thunderbird-2.0.0.9/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
           return "Home";
-//@line 150 "/export/home/mozilla/uild/thunderbird-2.0.0.0/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 150 "/export/home/mozilla/uild/thunderbird-2.0.0.9/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
         }
         
         function getDownloadsFolder(aFolder)
@@ -228,6 +228,10 @@ nsUnknownContentTypeDialog.prototype = {
       if (!aLocalFile || !aLocalFile.exists())
         return null;
 
+      // Remove any leading periods, since we don't want to save hidden files
+      // automatically.
+      aLeafName = aLeafName.replace(/^\.+/, "");
+
       if (aLeafName == "")
         aLeafName = "unnamed" + (aFileExt ? "." + aFileExt : "");
       aLocalFile.append(aLeafName);
@@ -241,6 +245,7 @@ nsUnknownContentTypeDialog.prototype = {
         f.remove(false);
         this.makeFileUnique(aLocalFile);
       }
+
       return aLocalFile;
     },
 
@@ -403,7 +408,7 @@ nsUnknownContentTypeDialog.prototype = {
         // want users to be able to autodownload .exe files. 
         var rememberChoice = this.dialogElement("rememberChoice");
 
-//@line 471 "/export/home/mozilla/uild/thunderbird-2.0.0.0/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 476 "/export/home/mozilla/uild/thunderbird-2.0.0.9/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
         if (shouldntRememberChoice) {
           rememberChoice.checked = false;
           rememberChoice.disabled = true;
@@ -536,12 +541,12 @@ nsUnknownContentTypeDialog.prototype = {
         var result;
 
         // The checking is different on Windows...
-//@line 617 "/export/home/mozilla/uild/thunderbird-2.0.0.0/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 622 "/export/home/mozilla/uild/thunderbird-2.0.0.9/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
             // On other platforms, default is Ok if there is a default app.
             // Note that nsIMIMEInfo providers need to ensure that this holds true
             // on each platform.
         return this.mLauncher.MIMEInfo.hasDefaultHandler;
-//@line 622 "/export/home/mozilla/uild/thunderbird-2.0.0.0/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 627 "/export/home/mozilla/uild/thunderbird-2.0.0.9/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
     },
     
     // Set "default" application description field.
@@ -562,9 +567,9 @@ nsUnknownContentTypeDialog.prototype = {
 
     // getPath:
     getPath: function (aFile) {
-//@line 645 "/export/home/mozilla/uild/thunderbird-2.0.0.0/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 650 "/export/home/mozilla/uild/thunderbird-2.0.0.9/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
       return aFile.path;
-//@line 647 "/export/home/mozilla/uild/thunderbird-2.0.0.0/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 652 "/export/home/mozilla/uild/thunderbird-2.0.0.9/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
     },
 
     // initAppAndSaveToDiskValues:
@@ -632,9 +637,9 @@ nsUnknownContentTypeDialog.prototype = {
       }
       
       // otherHandler is always disabled on Mac
-//@line 718 "/export/home/mozilla/uild/thunderbird-2.0.0.0/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 723 "/export/home/mozilla/uild/thunderbird-2.0.0.9/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
       otherHandler.nextSibling.hidden = otherHandler.nextSibling.nextSibling.hidden = false;
-//@line 720 "/export/home/mozilla/uild/thunderbird-2.0.0.0/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 725 "/export/home/mozilla/uild/thunderbird-2.0.0.9/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
       this.updateOKButton();
     },
 
@@ -788,7 +793,7 @@ nsUnknownContentTypeDialog.prototype = {
           // for the file to be saved to to pass to |saveToDisk| - otherwise
           // we must ask the user to pick a save name.
 
-//@line 887 "/export/home/mozilla/uild/thunderbird-2.0.0.0/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 892 "/export/home/mozilla/uild/thunderbird-2.0.0.9/src/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
           this.mLauncher.saveToDisk(null, false);
         }
         else
