@@ -1,4 +1,4 @@
-//@line 43 "/export/home/mozilla/uild/thunderbird-2.0.0.0/src/mozilla/mail/base/content/msgMail3PaneWindow.js"
+//@line 43 "/export/home/mozilla/uild/thunderbird-2.0.0.9/src/mozilla/mail/base/content/msgMail3PaneWindow.js"
 
 /* This is where functions related to the 3 pane window are kept */
 
@@ -847,7 +847,7 @@ function delayedOnLoadMessenger()
     gSearchEmailAddress = (window.arguments.length > 2) ? window.arguments[2] : null;
   }
 
-//@line 908 "/export/home/mozilla/uild/thunderbird-2.0.0.0/src/mozilla/mail/base/content/msgMail3PaneWindow.js"
+//@line 908 "/export/home/mozilla/uild/thunderbird-2.0.0.9/src/mozilla/mail/base/content/msgMail3PaneWindow.js"
 
   setTimeout("loadStartFolder(gStartFolderUri);", 0);
 
@@ -982,6 +982,8 @@ function loadStartFolder(initialUri)
       // this is the case where we're trying to auto-subscribe to a folder.
       if (initialUri && !startFolder.parent)
       {
+        // hack to force display of thread pane.
+        ShowingThreadPane();
         messenger.loadURL(window, initialUri);
         return;
       }
@@ -1682,11 +1684,6 @@ function SelectMessage(messageUri)
     gDBView.selectMsgByKey(msgHdr.messageKey);
 }
 
-function ReloadWithAllParts()
-{
-  gDBView.reloadMessageWithAllParts();
-}
-
 function ReloadMessage()
 {
   gDBView.reloadMessage();
