@@ -1,4 +1,4 @@
-//@line 38 "/export/home/mozilla/uild/thunderbird-2.0.0.0/src/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 38 "/export/home/mozilla/uild/thunderbird-2.0.0.9/src/mozilla/toolkit/mozapps/extensions/content/extensions.js"
 
 ///////////////////////////////////////////////////////////////////////////////
 // Globals
@@ -424,14 +424,14 @@ function getIDFromResourceURI(aURI)
 
 function openURL(aURL)
 {
-//@line 465 "/export/home/mozilla/uild/thunderbird-2.0.0.0/src/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 465 "/export/home/mozilla/uild/thunderbird-2.0.0.9/src/mozilla/toolkit/mozapps/extensions/content/extensions.js"
   var uri = Components.classes["@mozilla.org/network/io-service;1"]
                       .getService(nsIIOService).newURI(aURL, null, null);
 
   var protocolSvc = Components.classes["@mozilla.org/uriloader/external-protocol-service;1"]
                               .getService(Components.interfaces.nsIExternalProtocolService);
   protocolSvc.loadUrl(uri);
-//@line 481 "/export/home/mozilla/uild/thunderbird-2.0.0.0/src/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 481 "/export/home/mozilla/uild/thunderbird-2.0.0.9/src/mozilla/toolkit/mozapps/extensions/content/extensions.js"
 }
 
 function showProgressBar() {
@@ -559,6 +559,7 @@ function Startup()
     catch (e) {
       if (window.arguments[0] == "updates-only") {
         gUpdatesOnly = true;
+//@line 613 "/export/home/mozilla/uild/thunderbird-2.0.0.9/src/mozilla/toolkit/mozapps/extensions/content/extensions.js"
         document.getElementById("viewGroup").hidden = true;
         document.getElementById("extensionsView").setAttribute("norestart", "");
         showView("updates");
@@ -976,8 +977,10 @@ var gAddonContextMenus = ["menuitem_useTheme", "menuitem_options", "menuitem_hom
                           "menuitem_cancelUninstall", "menuitem_checkUpdate",
                           "menuitem_enable", "menuitem_disable"];
 var gUpdateContextMenus = ["menuitem_homepage", "menuitem_about", "menuseparator_1",
-                           "menuitem_installUpdate", "menuitem_includeUpdate"]
-var gInstallContextMenus = ["menuitem_homepage", "menuitem_about"]
+                           "menuitem_installUpdate", "menuitem_includeUpdate"];
+// For browsers don't display context menuitems that can open a browser window.
+var gUpdateContextMenusNoBrowser = ["menuitem_installUpdate", "menuitem_includeUpdate"];
+var gInstallContextMenus = ["menuitem_homepage", "menuitem_about"];
 
 function buildContextMenu(aEvent)
 {
@@ -1126,7 +1129,7 @@ var gExtensionsDNDObserver =
     // XXXrstrong - bug 269568, GTK2 drag and drop is returning invalid data for
     // dragenter and dragover. To workaround this we always set canDrop to true
     // and just use the xfer data returned in ondrop which is valid.
-//@line 1176 "/export/home/mozilla/uild/thunderbird-2.0.0.0/src/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 1183 "/export/home/mozilla/uild/thunderbird-2.0.0.9/src/mozilla/toolkit/mozapps/extensions/content/extensions.js"
     this._ensureServices();
 
     var count = aDragSession.numDropItems;
@@ -1137,7 +1140,7 @@ var gExtensionsDNDObserver =
         return;
       }
     }
-//@line 1187 "/export/home/mozilla/uild/thunderbird-2.0.0.0/src/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 1194 "/export/home/mozilla/uild/thunderbird-2.0.0.9/src/mozilla/toolkit/mozapps/extensions/content/extensions.js"
     this._canDrop = true;
   },
 
